@@ -1,11 +1,12 @@
 package Constant::Generator;
 
+require 5.006001;
 use Carp;
 use strict;
 use warnings 'all';
 no warnings 'uninitialized';
 
-our $VERSION = '1.012';
+our $VERSION = '1.013';
 our %GEN;
 
 my ($idx, $fl_set_ldr, $c);
@@ -80,7 +81,7 @@ sub gen{
 	$@ && die("Constant generation error: $@");
     }
 
-    my $fn = $pkg; $fn=~s/::/\//o; $fn .= '.pm';
+    my $fn = $pkg; $fn=~s/::/\//og; $fn .= '.pm';
     if(!$h->{fl_no_load} and $h->{fl_no_ldr}){
 	$h->{fl_no_inc_stub} or $INC{$fn} = ''
     }
@@ -122,7 +123,7 @@ Constant::Generator - this module bring flexible (I hope) constant generator to
 
 =head1 VERSION
 
-version 1.012
+version 1.013
 
 =head1 DESCRIPTION
 
